import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface LogsIndexConfig extends cdktf.TerraformMetaArguments {
    /**
     * The name of the index.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/logs_index.html#name LogsIndex#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * exclusion_filter block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/logs_index.html#exclusion_filter LogsIndex#exclusion_filter}
     *
     * @stability stable
     */
    readonly exclusionFilter?: LogsIndexExclusionFilter[];
    /**
     * filter block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/logs_index.html#filter LogsIndex#filter}
     *
     * @stability stable
     */
    readonly filter: LogsIndexFilter[];
}
/**
 * @stability stable
 */
export interface LogsIndexExclusionFilterFilter {
    /**
     * Only logs matching the filter criteria and the query of the parent index will be considered for this exclusion filter.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/logs_index.html#query LogsIndex#query}
     *
     * @stability stable
     */
    readonly query?: string;
    /**
     * The fraction of logs excluded by the exclusion filter, when active.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/logs_index.html#sample_rate LogsIndex#sample_rate}
     *
     * @stability stable
     */
    readonly sampleRate?: number;
}
/**
 * @stability stable
 */
export interface LogsIndexExclusionFilter {
    /**
     * A boolean stating if the exclusion is active or not.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/logs_index.html#is_enabled LogsIndex#is_enabled}
     *
     * @stability stable
     */
    readonly isEnabled?: boolean;
    /**
     * The name of the exclusion filter.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/logs_index.html#name LogsIndex#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * filter block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/logs_index.html#filter LogsIndex#filter}
     *
     * @stability stable
     */
    readonly filter?: LogsIndexExclusionFilterFilter[];
}
/**
 * @stability stable
 */
export interface LogsIndexFilter {
    /**
     * Logs filter criteria. Only logs matching this filter criteria are considered for this index.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/logs_index.html#query LogsIndex#query}
     *
     * @stability stable
     */
    readonly query: string;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/datadog/r/logs_index.html datadog_logs_index}.
 *
 * @stability stable
 */
export declare class LogsIndex extends cdktf.TerraformResource {
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/datadog/r/logs_index.html datadog_logs_index} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: LogsIndexConfig);
    /**
     * @stability stable
     */
    get id(): string;
    private _name;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string;
    private _exclusionFilter?;
    /**
     * @stability stable
     */
    get exclusionFilter(): LogsIndexExclusionFilter[];
    /**
     * @stability stable
     */
    set exclusionFilter(value: LogsIndexExclusionFilter[]);
    /**
     * @stability stable
     */
    resetExclusionFilter(): void;
    /**
     * @stability stable
     */
    get exclusionFilterInput(): LogsIndexExclusionFilter[] | undefined;
    private _filter;
    /**
     * @stability stable
     */
    get filter(): LogsIndexFilter[];
    /**
     * @stability stable
     */
    set filter(value: LogsIndexFilter[]);
    /**
     * @stability stable
     */
    get filterInput(): LogsIndexFilter[];
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
